@@ -361,7 +361,13 @@ class WP_REST_Posts_Controller extends WP_REST_Controller {
 		$posts = array();
 
 		foreach ( $query_result as $post ) {
-			if ( ! $this->check_read_permission( $post ) ) {
+			if ( 'edit' === $request['context'] ) {
+				$permission = $this->check_update_permission( $post );
+			} else {
+				$permission = $this->check_read_permission( $post );
+			}
+
+			if ( ! $permission ) {
 				continue;
 			}
 
